# sgGWR

## Installation
We recommend installing [JAX](https://github.com/google/jax)] package for efficient computation.
To install sgGWR with JAX, please execute the following on your terminal.

```
pip install sgGWR[jax]
```

If you cannot install JAX (e.g., Windows users), you can omit `[jax]` option.

```
pip install sgGWR
```


